@@ -57,8 +57,10 @@ pref("general.open_location.last_window_choice", 0);
 pref("general.smoothScroll", false);
 pref("general.autoScroll", true);
 
-pref("general.useragent.extra.seamonkey", "SeaMonkey/1.0.5");
-//@line 61 "/home/robert/tinderbox/release-SeaMonkey-1.0/Linux_2.4.21-303-default_Clobber/mozilla/xpfe/bootstrap/browser-prefs.js"
+pref("general.warnOnAboutConfig", true);
+
+pref("general.useragent.extra.seamonkey", "SeaMonkey/1.1b");
+//@line 63 "/home/robert/tinderbox/release-SeaMonkey-1.1/Linux_2.4.21-303-default_Clobber/mozilla/xpfe/bootstrap/browser-prefs.js"
 
 // 0 = blank, 1 = home (browser.startup.homepage), 2 = last
 pref("browser.startup.page",                1);
@@ -101,6 +103,7 @@ pref("browser.download.lastLocation", true);
 // various default search settings
 pref("browser.search.defaulturl", "chrome://navigator-region/locale/region.properties");
 pref("browser.search.opensidebarsearchpanel", true);
+pref("browser.search.opentabforcontextsearch", false);
 pref("browser.search.last_search_category", "NC:SearchCategory?category=urn:search:category:1");
 pref("browser.search.mode", 0);
 // basic search popup constraint: minimum sherlock plugin version displayed
@@ -122,6 +125,8 @@ pref("browser.tabs.loadDivertedInBackground", false);
 pref("browser.tabs.loadInBackground", false);
 pref("browser.tabs.opentabfor.middleclick", false);
 pref("browser.tabs.opentabfor.urlbar", false);
+pref("browser.tabs.tooltippreview.enable", true);
+pref("browser.tabs.tooltippreview.width", 300);
 
 // external link handling in tabbed browsers. values from nsIBrowserDOMWindow.
 // 0=default window, 1=current window/tab, 2=new window, 3=new tab in most recent window
@@ -184,6 +189,13 @@ pref("news.directory",                  "");
 pref("browser.editor.disabled", false);
 pref("spellchecker.dictionary", "");
 
+// this will automatically enable inline spellchecking (if it is available) for
+// editable elements in HTML
+// 0 = spellcheck nothing
+// 1 = check multi-line controls [default]
+// 2 = check multi/single line controls
+pref("layout.spellcheckDefault", 1);
+
 pref("xpinstall.dialog.confirm",        "chrome://communicator/content/xpinstall/institems.xul");
 pref("xpinstall.dialog.progress.chrome","chrome://communicator/content/xpinstall/xpistatus.xul");
 pref("xpinstall.dialog.progress.skin",  "chrome://communicator/content/xpinstall/xpistatus.xul");
@@ -240,9 +252,9 @@ pref("dom.disable_window_flip",        true);
 // prevent JS from disabling or replacing context menus
 pref("dom.event.contextmenu.enabled",  true);
 
-//@line 250 "/home/robert/tinderbox/release-SeaMonkey-1.0/Linux_2.4.21-303-default_Clobber/mozilla/xpfe/bootstrap/browser-prefs.js"
+//@line 265 "/home/robert/tinderbox/release-SeaMonkey-1.1/Linux_2.4.21-303-default_Clobber/mozilla/xpfe/bootstrap/browser-prefs.js"
 
-//@line 253 "/home/robert/tinderbox/release-SeaMonkey-1.0/Linux_2.4.21-303-default_Clobber/mozilla/xpfe/bootstrap/browser-prefs.js"
+//@line 268 "/home/robert/tinderbox/release-SeaMonkey-1.1/Linux_2.4.21-303-default_Clobber/mozilla/xpfe/bootstrap/browser-prefs.js"
 // For the download dialog
 pref("browser.download.progressDnldDialog.enable_launch_reveal_buttons", false);
 pref("browser.urlbar.clickSelectsAll", false);
@@ -253,9 +265,3 @@ pref("browser.urlbar.clickSelectsAll", false);
 pref("browser.backspace_action", 1);
 
 pref("general.autoScroll", false);
-//@line 265 "/home/robert/tinderbox/release-SeaMonkey-1.0/Linux_2.4.21-303-default_Clobber/mozilla/xpfe/bootstrap/browser-prefs.js"
-
-// XXX This should really be in mailnews.js, however so that we can
-// ship it for SeaMonkey 1.0 we're putting it here for the Gecko 1.8 branch.
-// Trunk already has it in mailnews.js.
-pref("mail.addr_book.im.onlineCheckAllowed", false);
